@@ -1,11 +1,10 @@
-import pprint
+from w3lib.url import is_url
 
-from scrapy import log
 from scrapy.command import ScrapyCommand
-from scrapy.core.manager import scrapymanager
 from scrapy.http import Request
-from scrapy.spider import BaseSpider, spiders
-from scrapy.utils.url import is_url
+from scrapy.spider import BaseSpider
+from scrapy.exceptions import UsageError
+from scrapy.utils.spider import create_spider_for_request
 
 class Command(ScrapyCommand):
 
@@ -28,27 +27,32 @@ class Command(ScrapyCommand):
         parser.add_option("--headers", dest="headers", action="store_true", \
             help="print response HTTP headers instead of body")
 
+    def _print_headers(self, headers, prefix):
+        for key, values in headers.items():
+            for value in values:
+                print '%s %s: %s' % (prefix, key, value)
+
     def _print_response(self, response, opts):
         if opts.headers:
-            pprint.pprint(response.headers)
+            self._print_headers(response.request.headers, '>')
+            print '>'
+            self._print_headers(response.headers, '<')
         else:
             print response.body
 
     def run(self, args, opts):
         if len(args) != 1 or not is_url(args[0]):
-            return False
+            raise UsageError()
         cb = lambda x: self._print_response(x, opts)
         request = Request(args[0], callback=cb, dont_filter=True)
+        request.meta['handle_httpstatus_all'] = True
 
+        crawler = self.crawler_process.create_crawler()
         spider = None
         if opts.spider:
-            try:
-                spider = spiders.create(opts.spider)
-            except KeyError:
-                log.msg("Could not find spider: %s" % opts.spider, log.ERROR)
-
-        scrapymanager.configure()
-        scrapymanager.queue.append_request(request, spider, \
-            default_spider=BaseSpider('default'))
-        scrapymanager.start()
-
+            spider = crawler.spiders.create(opts.spider)
+        else:
+            spider = create_spider_for_request(crawler.spiders, request, \
+                default_spider=BaseSpider('default'))
+        crawler.crawl(spider, [request])
+        self.crawler_process.start()
