@@ -6,33 +6,35 @@ enable this middleware and enable the ROBOTSTXT_OBEY setting.
 
 import robotparser
 
-from scrapy.xlib.pydispatch import dispatcher
-
 from scrapy import signals, log
-from scrapy.project import crawler
 from scrapy.exceptions import NotConfigured, IgnoreRequest
 from scrapy.http import Request
 from scrapy.utils.httpobj import urlparse_cached
-from scrapy.conf import settings
 
 class RobotsTxtMiddleware(object):
     DOWNLOAD_PRIORITY = 1000
 
-    def __init__(self):
-        if not settings.getbool('ROBOTSTXT_OBEY'):
+    def __init__(self, crawler):
+        if not crawler.settings.getbool('ROBOTSTXT_OBEY'):
             raise NotConfigured
 
+        self.crawler = crawler
         self._parsers = {}
         self._spider_netlocs = {}
         self._useragents = {}
-        dispatcher.connect(self.spider_opened, signals.spider_opened)
-        dispatcher.connect(self.spider_closed, signals.spider_closed)
+        crawler.signals.connect(self.spider_opened, signals.spider_opened)
+        crawler.signals.connect(self.spider_closed, signals.spider_closed)
+
+    @classmethod
+    def from_crawler(cls, crawler):
+        return cls(crawler)
 
     def process_request(self, request, spider):
         useragent = self._useragents[spider]
         rp = self.robot_parser(request, spider)
         if rp and not rp.can_fetch(useragent, request.url):
-            log.msg("Forbidden by robots.txt: %s" % request, log.DEBUG)
+            log.msg(format="Forbidden by robots.txt: %(request)s",
+                    level=log.DEBUG, request=request)
             raise IgnoreRequest
 
     def robot_parser(self, request, spider):
@@ -42,7 +44,7 @@ class RobotsTxtMiddleware(object):
             self._parsers[netloc] = None
             robotsurl = "%s://%s/robots.txt" % (url.scheme, url.netloc)
             robotsreq = Request(robotsurl, priority=self.DOWNLOAD_PRIORITY)
-            dfd = crawler.engine.download(robotsreq, spider)
+            dfd = self.crawler.engine.download(robotsreq, spider)
             dfd.addCallback(self._parse_robots)
             self._spider_netlocs[spider].add(netloc)
         return self._parsers[netloc]
@@ -54,8 +56,7 @@ class RobotsTxtMiddleware(object):
 
     def spider_opened(self, spider):
         self._spider_netlocs[spider] = set()
-        self._useragents[spider] = getattr(spider, 'user_agent', None) \
-            or settings['USER_AGENT']
+        self._useragents[spider] = spider.settings['USER_AGENT']
 
     def spider_closed(self, spider):
         for netloc in self._spider_netlocs[spider]:
