@@ -320,6 +320,18 @@ class FormRequestTest(RequestTest):
         fs = _qs(req)
         self.assertEqual(fs, {'i1': ['i1v']})
 
+    def test_from_response_dont_submit_reset_as_input(self):
+        response = _buildresponse(
+            """<form>
+            <input type="hidden" name="i1" value="i1v">
+            <input type="text" name="i2" value="i2v">
+            <input type="reset" name="resetme">
+            <input type="submit" name="i3" value="i3v">
+            </form>""")
+        req = self.request_class.from_response(response, dont_click=True)
+        fs = _qs(req)
+        self.assertEqual(fs, {'i1': ['i1v'], 'i2': ['i2v']})
+
     def test_from_response_multiple_clickdata(self):
         response = _buildresponse(
             """<form action="get.php" method="GET">
